@@ -102,7 +102,7 @@ sub ApplyLimits {
     if ( $per_page) {
         $limit_clause = " LIMIT ";
         $limit_clause .= $per_page;
-        if ( $first != 0 ) {
+        if ( $first && $first != 0 ) {
             $limit_clause .= " OFFSET $first";
         }
     }
@@ -261,20 +261,23 @@ Returns a FIELD OPERATOR VALUE triple.
 =cut
 
 sub _MakeClauseCaseInsensitive {
-    my $self = shift;
-    my $field = shift;
+    my $self     = shift;
+    my $field    = shift;
     my $operator = shift;
-    my $value = shift;
- 
+    my $value    = shift;
 
-
-    if  ($operator =~ /LIKE/i ) {
-        $operator =~ s/LIKE/ILIKE/ig; 
-        return ($field, $operator, $value);
-    } elsif ($operator eq '=') {
-        return ($field,'ILIKE',$value);
-    } else {
-        $self->SUPER::_MakeClauseCaseInsensitive($field, $operator,$value);
+    if ( $operator =~ /LIKE/i ) {
+        $operator =~ s/LIKE/ILIKE/ig;
+        return ( $field, $operator, $value );
+    }
+    elsif ( $operator =~ /\s*!=\s*/ ) {
+        return ( $field, 'NOT ILIKE', $value );
+    }
+    elsif ( $operator =~ /\s*=\s*/ ) {
+        return ( $field, 'ILIKE', $value );
+    }
+    else {
+        $self->SUPER::_MakeClauseCaseInsensitive( $field, $operator, $value );
     }
 }
 
